@@ -1,15 +1,12 @@
-use ansiterm::Style;
+use nu_ansi_term::Style;
 
 use crate::fs::fields as f;
-use crate::output::cell::{TextCell, DisplayWidth};
-
+use crate::output::cell::{DisplayWidth, TextCell};
 
 impl f::SecurityContext<'_> {
     pub fn render<C: Colours>(&self, colours: &C) -> TextCell {
         match &self.context {
-            f::SecurityContextType::None => {
-                TextCell::paint_str(colours.none(), "?")
-            }
+            f::SecurityContextType::None => TextCell::paint_str(colours.none(), "?"),
             f::SecurityContextType::SELinux(context) => {
                 let mut chars = Vec::with_capacity(7);
 
@@ -18,7 +15,7 @@ impl f::SecurityContext<'_> {
                         0 => colours.selinux_user(),
                         1 => colours.selinux_role(),
                         2 => colours.selinux_type(),
-                        _ => colours.selinux_range()
+                        _ => colours.selinux_range(),
                     };
                     if i > 0 {
                         chars.push(colours.selinux_colon().paint(":"));
@@ -28,15 +25,16 @@ impl f::SecurityContext<'_> {
 
                 TextCell {
                     contents: chars.into(),
-                    width: DisplayWidth::from(context.len())
+                    width: DisplayWidth::from(context.len()),
                 }
             }
         }
     }
 }
 
+#[rustfmt::skip]
 pub trait Colours {
-    fn none(&self)          -> Style;
+    fn none(&self) -> Style;
     fn selinux_colon(&self) -> Style;
     fn selinux_user(&self)  -> Style;
     fn selinux_role(&self)  -> Style;
